..
   SPDX-FileCopyrightText: Copyright DB Netz AG and the capellambse contributors
   SPDX-License-Identifier: Apache-2.0

The |project| Sphinx extension
==============================

.. automodule:: capellambse.sphinx
